{{
''*******************************************
''*  Scale Utility                          *
''*                                         *
''*  Author: Timothy Meyers                 *
''*******************************************

    Program Scale.Spin ... This program (or rather object) scales values
    for use in other applications. Helps duplicate the scroll bar functions
    available while using the PLX-DAQ macro I modified with a scroll bar.

Revision History:
  Version 1.0   - (06/20/2012) initial release

  Example:

        M.Start(-1,1,99)                ' meter output signal  (-1=Auto)
        Y.Start(-1,0,359)               ' radial heading           "
        Z.Start(-1,$E000,$EFFF)         ' sin table address        "
        
    durring init:
        RCTime.Start(PotY_Pin,1,@Pot_Y) ' start continous update 1st
        
    then later read table:    
        J := Word[Z.GetScaled(Pot_Y)]   ' use pot to index sin table entries
        
}}
CON
  _CLKMODE = XTAL1 + PLL16X
  _XINFREQ = 5_000_000

VAR
    Long SMax,SMin,Gain                        ' slider values
    Byte Stopped, Auto
    Long ScaleMax

PUB Stop
  SMax~
  SMin~
  Gain~
  ScaleMax := 1
  Stopped := true
  Auto := false

PUB Start(aScale, aMin, aMax)
  Stop
  SetMin(aMin)
  SetMax(aMax)
  if aScale < 0
    Auto := true
  else
    ScaleMax := aScale

PUB SetMax(aValue)                         ' Procedure - Set max value for slider
  if (SMax := aValue) > SMin
    Stopped := False
    ReScale
  else
    Stopped := True

PUB SetMin(aValue)                         ' Procedure - Set min value for slider
  if (SMin := aValue) < SMax
    Stopped := False
    ReScale
  else
    Stopped := True

PUB GetScaled(aValue)     ' Function - Return the scaled value
  if not stopped
    if auto and aValue > ScaleMax
      ScaleMax := aValue
      ReScale
    return Smin #> (aValue/Gain + Smin) <# SMax
  else
    return aValue               ' go back with raw unscaled input

PUB ReScale
  Gain := 1 #> (ScaleMax / (SMax-SMin))
return

PUB GetScaleMax

return ScaleMax